@@ -8,24 +8,16 @@ use noodles_bam as bam;
 use noodles_sam::{self as sam, record::data::field::Tag};
 
 fn is_unique_record(record: &bam::Record) -> io::Result<bool> {
-    for result in record.data().values() {
-        let field = result?;
-
-        if field.tag() == Tag::AlignmentHitCount {
-            let value = field.value();
-
-            if let Some(hits) = value.as_int() {
-                return Ok(hits == 1);
-            } else {
-                return Err(io::Error::new(
-                    io::ErrorKind::InvalidData,
-                    format!("expected integer, got {:?}", value),
-                ));
-            }
-        }
+    match record.data().get(Tag::AlignmentHitCount) {
+        Some(Ok(field)) => field.value().as_int().map(|hits| hits == 1).ok_or_else(|| {
+            io::Error::new(
+                io::ErrorKind::InvalidData,
+                format!("expected integer, got {:?}", field.value()),
+            )
+        }),
+        Some(Err(e)) => Err(e),
+        None => Ok(false),
     }
-
-    Ok(false)
 }
 
 fn main() -> Result<(), Box<dyn std::error::Error>> {
