@@ -210,15 +210,24 @@ impl From<Vec<u32>> for Cigar {
     }
 }
 
+impl From<Vec<Op>> for Cigar {
+    fn from(ops: Vec<Op>) -> Self {
+        let raw_ops = ops.into_iter().map(u32::from).collect();
+        Self(raw_ops)
+    }
+}
+
 impl TryFrom<&Cigar> for sam::record::Cigar {
     type Error = io::Error;
 
     fn try_from(cigar: &Cigar) -> Result<Self, Self::Error> {
+        use sam::record::cigar::Op;
+
         let mut ops = Vec::new();
 
         for result in cigar.ops() {
             let op = result?;
-            ops.push(sam::record::cigar::Op::new(op.kind(), op.len()));
+            ops.push(Op::from(op));
         }
 
         Ok(Self::from(ops))
@@ -230,31 +239,27 @@ mod tests {
     use super::*;
 
     #[test]
-    fn test_from_bytes() -> Result<(), Box<dyn std::error::Error>> {
-        let data = vec![0x00000240, 0x00000362]; // 36MD54
-        let cigar = Cigar::from(data);
-
-        let mut ops = cigar.ops();
-
-        assert_eq!(ops.next().transpose()?, Some(Op::try_from(0x240)?));
-        assert_eq!(ops.next().transpose()?, Some(Op::try_from(0x362)?));
-        assert_eq!(ops.next().transpose()?, None);
+    fn test_from_vec_u8_for_cigar() {
+        let cigar = Cigar::from(vec![0x00000240, 0x00000084]); // 36M8S
+        assert_eq!(cigar.as_ref(), [0x00000240, 0x00000084]);
+    }
 
+    #[test]
+    fn test_from_vec_ops_for_cigar() -> Result<(), op::LengthError> {
+        let cigar = Cigar::from(vec![Op::new(Kind::Match, 36)?, Op::new(Kind::SoftClip, 8)?]);
+        assert_eq!(cigar.as_ref(), [0x00000240, 0x00000084]);
         Ok(())
     }
 
     #[test]
     fn test_try_from_cigar_for_sam_record_cigar() -> io::Result<()> {
-        use sam::record::cigar::{op, Op};
+        use sam::record::cigar::{op::Kind, Op};
 
-        let data = vec![0x00000240, 0x00000362]; // 36MD54
-        let cigar = Cigar::from(data);
+        let cigar = Cigar::from(vec![0x00000240, 0x00000084]); // 36M8S
 
         let actual = sam::record::Cigar::try_from(&cigar)?;
-        let expected = sam::record::Cigar::from(vec![
-            Op::new(op::Kind::Match, 36),
-            Op::new(op::Kind::Deletion, 54),
-        ]);
+        let expected =
+            sam::record::Cigar::from(vec![Op::new(Kind::Match, 36), Op::new(Kind::SoftClip, 8)]);
 
         assert_eq!(actual, expected);
 
